@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.46.2.5 2004/06/11 12:17:14 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.46.2.6 2004/06/16 05:28:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -64,6 +64,10 @@ static void bbs_thread_view_realize(GtkWidget *widget);
 
 static gboolean bbs_thread_view_motion_notify(GtkWidget *widget,
 					      GdkEventMotion *event);
+#if GRAB_FOCUS_ON_ENTER_NOTIFY
+static gboolean bbs_thread_view_enter_notify(GtkWidget *widget,
+					     GdkEventCrossing *event);
+#endif
 static gboolean bbs_thread_view_leave_notify(GtkWidget *widget,
 					     GdkEventCrossing *event);
 static gboolean bbs_thread_view_button_press(GtkWidget *widget,
@@ -448,6 +452,9 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
 
   widget_class->realize = bbs_thread_view_realize;
   widget_class->motion_notify_event = bbs_thread_view_motion_notify;
+#if GRAB_FOCUS_ON_ENTER_NOTIFY
+  widget_class->enter_notify_event = bbs_thread_view_enter_notify;
+#endif
   widget_class->leave_notify_event = bbs_thread_view_leave_notify;
   widget_class->button_press_event = bbs_thread_view_button_press;
   widget_class->button_release_event = bbs_thread_view_button_release;
@@ -812,6 +819,20 @@ bbs_thread_view_motion_notify(GtkWidget *widget, GdkEventMotion *event)
 }
 
 
+#if GRAB_FOCUS_ON_ENTER_NOTIFY
+static gboolean
+bbs_thread_view_enter_notify(GtkWidget *widget, GdkEventCrossing *event)
+{
+  gtk_widget_grab_focus(widget);
+
+  if (GTK_WIDGET_CLASS(parent_class)->enter_notify_event != NULL)
+    return (*GTK_WIDGET_CLASS(parent_class)->enter_notify_event)(widget,
+								 event);
+  return FALSE;
+}
+#endif
+
+
 static gboolean
 bbs_thread_view_leave_notify(GtkWidget *widget, GdkEventCrossing *event)
 {
