@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.92.2.3 2004/05/15 15:41:22 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.92.2.5 2004/06/13 22:55:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -800,8 +800,6 @@ font_selection_dialog_response_cb(GtkWidget *dialog, int response_id,
 
   g_return_if_fail(GTK_IS_FONT_SELECTION_DIALOG(dialog));
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   font_selection = GTK_FONT_SELECTION_DIALOG(dialog);
 
   switch (response_id)
@@ -810,8 +808,6 @@ font_selection_dialog_response_cb(GtkWidget *dialog, int response_id,
       font_name = gtk_font_selection_dialog_get_font_name(font_selection);
       preview_tree_view_font(application, font_name);
       g_free(font_name);
-
-      ENTER_MAIN_EVENT_LOOP();
       return;
 
     case GTK_RESPONSE_OK:
@@ -834,8 +830,6 @@ font_selection_dialog_response_cb(GtkWidget *dialog, int response_id,
       g_free(tree_view_font_name);
       tree_view_font_name = NULL;
     }
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1018,8 +1012,6 @@ static void
 text_search_window_response_cb(TextSearchWindow *window, int response_id,
 			       OchushaApplication *application)
 {
-  MAIN_THREAD_EVENT_CALLBACK();
-
   switch (response_id)
     {
     case GTK_RESPONSE_DELETE_EVENT:
@@ -1032,13 +1024,8 @@ text_search_window_response_cb(TextSearchWindow *window, int response_id,
 	threadlist_view_set_being_searched(search_query_data.last_view, FALSE);
       search_query_data.last_view = NULL;
       gtk_widget_hide(GTK_WIDGET(window));
-
-      ENTER_MAIN_EVENT_LOOP();
-
       return;
     }
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1089,8 +1076,6 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
   gboolean result;
   gchar *normalized_key;
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   application->threadlist_search_direction = direction;
   application->threadlist_search_enable_wrap = enable_wrap;
   application->threadlist_search_match_case = match_case;
@@ -1144,8 +1129,6 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
   else
     result = do_search_on_current_threadlist(application, TRUE);
 
-  ENTER_MAIN_EVENT_LOOP();
-
   return result;
 }
 
@@ -1157,15 +1140,7 @@ text_search_window_find_next_cb(TextSearchWindow *window, const gchar *key,
 				gboolean use_regexp,
 				OchushaApplication *application)
 {
-  gboolean result;
-
-  MAIN_THREAD_EVENT_CALLBACK();
-
-  result = do_search_on_current_threadlist(application, FALSE);
-
-  ENTER_MAIN_EVENT_LOOP();
-
-  return result;
+  return do_search_on_current_threadlist(application, FALSE);
 }
 
 
@@ -1332,8 +1307,6 @@ filter_toggled_cb(GObject *unused,
     return;
 #endif
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   info->enable_filter = !info->enable_filter;
 
 #if GTK_MINOR_VERSION <= 2
@@ -1344,11 +1317,9 @@ filter_toggled_cb(GObject *unused,
 				    info->enable_filter);
 #endif
 
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
   redraw_threadlist_view(application, board);
-  OCHU_THREADS_ENTER();
-
-  ENTER_MAIN_EVENT_LOOP();
+  gdk_threads_enter();
 }
 
 
@@ -1418,8 +1389,6 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
   BulletinBoardGUIInfo *info
     = ensure_bulletin_board_info(board, application);
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   /*
    * MEMO: ɽƤ륦åȤºݤ˼ΤƤ륿ߥ
    *       򤺤餹
@@ -1440,11 +1409,11 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
    */
   if (buffer != NULL)
     {
-      OCHU_THREADS_LEAVE();
+      gdk_threads_leave();
       ochusha_async_buffer_suspend(buffer);
       ochusha_async_buffer_terminate(buffer);
       /* ochusha_async_buffer_resume(buffer); */
-      OCHU_THREADS_ENTER();
+      gdk_threads_enter();
     }
 
   if (item_view != NULL)
@@ -1483,8 +1452,6 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
 			   info->message_id);
       info->message_id = 0;
     }
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1506,6 +1473,12 @@ item_view_closed_cb(PanedNotebook *paned_notebook, OchushaBulletinBoard *board,
   gtk_widget_hide(item_view);
   gtk_widget_unrealize(item_view);
   delayed_g_object_unref(G_OBJECT(item_view));
+
+  if (ochusha_bulletin_board_trylock_thread_list(board))
+    {
+      write_threadlist(board, application);
+      ochusha_bulletin_board_unlock_thread_list(board);
+    }
 }
 
 
@@ -2017,19 +1990,11 @@ process_board_move(OchushaBulletinBoard *old_board,
 		   OchushaBulletinBoard *new_board,
 		   gpointer user_data)
 {
-#if 0
   OchushaApplication *application = (OchushaApplication *)user_data;
-#endif  
-  /*
-   * TODO: DATեʤɥå夷ƤǡΰžԤ٤
-   *       İžɤߤGUIɲäɬפ⡣
-   */
-#if DEBUG_GUI
-  fprintf(stderr, "process_board_move: old_board=%p new_board=%p\n",
-	  old_board, new_board);
-#endif
-  ochusha_bulletin_board_set_base_url(old_board,
-			ochusha_bulletin_board_get_base_url(new_board));
+  const char *new_base_url = ochusha_bulletin_board_get_base_url(new_board);
+  ochusha_bulletin_board_process_board_move(old_board, new_base_url,
+					    &application->config);
+
   return old_board;
 }
 
@@ -2092,12 +2057,9 @@ build_boardlist(WorkerThread *employee, gpointer args)
 					process_board_move,
 					application))
     {
-      OCHU_THREADS_ENTER();
-
+      gdk_threads_enter();
       setup_boardlist(application);
-
-      OCHU_THREADS_LEAVE();
-
+      gdk_threads_leave();
       ochusha_bbs_table_write_boardlist_xml(table, &application->config,
 					    application->session_subdir);
       if (application->session_subdir != NULL)
@@ -2146,11 +2108,7 @@ setup_boardlist(OchushaApplication *application)
 static void
 make_new_thread_button_cb(GObject *unused, OchushaApplication *application)
 {
-  MAIN_THREAD_EVENT_CALLBACK();
-
   make_new_thread(application);
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2158,22 +2116,14 @@ static void
 open_board_properties_button_cb(GObject *unused,
 				OchushaApplication *application)
 {
-  MAIN_THREAD_EVENT_CALLBACK();
-
   open_current_board_properties(application);
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
 refresh_board_button_cb(GObject *unused, OchushaApplication *application)
 {
-  MAIN_THREAD_EVENT_CALLBACK();
-
   refresh_current_threadlist(application);
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2181,11 +2131,7 @@ static void
 start_threadlist_search_button_cb(GObject *unused,
 				  OchushaApplication *application)
 {
-  MAIN_THREAD_EVENT_CALLBACK();
-
   start_current_threadlist_search(application);
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2198,14 +2144,10 @@ new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
   guint message_id = (guint)g_object_get_data(G_OBJECT(dialog),
 					      "statusbar_message");
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   if (response_id == GTK_RESPONSE_REJECT)
     {
       ResponseEditor *editor = g_object_get_data(G_OBJECT(dialog), "editor");
       response_editor_clear_response(editor);
-
-      ENTER_MAIN_EVENT_LOOP();
       return;
     }
 
@@ -2240,12 +2182,12 @@ new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
 					  new_thread_netstat_id,
 					  statusbar_message);
 
-	  OCHU_THREADS_LEAVE();
+	  gdk_threads_leave();
 	  result = ochusha_bulletin_board_create_new_thread(board,
 						application->broker,
 						title, &response,
 						application->dolib_use_id_for_posting);
-	  OCHU_THREADS_ENTER();
+	  gdk_threads_enter();
 	  g_free(message);
 	  if (result)
 	    {
@@ -2323,8 +2265,6 @@ new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
     ochusha_open_url(application,
 		     ochusha_bulletin_board_get_base_url(board),
 		     FALSE, TRUE);
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
