@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.35.2.2 2004/06/11 12:17:14 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.35.2.3 2004/06/16 05:28:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -86,6 +86,10 @@ static void tree_view_row_expanded_cb(GtkTreeView *tree_view,
 static void tree_view_row_collapsed_cb(GtkTreeView *tree_view,
 				       GtkTreeIter *iter, GtkTreePath *path,
 				       BoardlistView *view);
+#if GRAB_FOCUS_ON_ENTER_NOTIFY
+static gboolean boardlist_view_enter_notify(GtkWidget *widget,
+					    GdkEventCrossing *event);
+#endif
 static gboolean boardlist_view_button_press(GtkWidget *widget,
 					    GdkEventButton *event);
 static gboolean boardlist_view_button_release(GtkWidget *widget,
@@ -735,6 +739,9 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 			       G_TYPE_ENUM, GTK_MOVEMENT_PAGES,
 			       G_TYPE_INT, -1);
 
+#if GRAB_FOCUS_ON_ENTER_NOTIFY
+  widget_class->enter_notify_event = boardlist_view_enter_notify;
+#endif
   widget_class->button_press_event = boardlist_view_button_press;
   widget_class->button_release_event = boardlist_view_button_release;
 
@@ -1585,6 +1592,20 @@ boardlist_view_new(void)
 }
 
 
+#if GRAB_FOCUS_ON_ENTER_NOTIFY
+static gboolean
+boardlist_view_enter_notify(GtkWidget *widget, GdkEventCrossing *event)
+{
+  gtk_widget_grab_focus(widget);
+
+  if (GTK_WIDGET_CLASS(parent_class)->enter_notify_event != NULL)
+    return (*GTK_WIDGET_CLASS(parent_class)->enter_notify_event)(widget,
+								 event);
+  return FALSE;
+}
+#endif
+
+
 static gboolean
 boardlist_view_button_press(GtkWidget *widget, GdkEventButton *event)
 {
