@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.36.2.1 2004/06/11 12:02:05 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.36.2.2 2004/06/14 10:28:39 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -300,6 +300,8 @@ void threadlist_view_remove_thread(ThreadlistView *view,
 
 void threadlist_view_scroll_to_thread(ThreadlistView *view,
 				      OchushaBBSThread *thread);
+void threadlist_view_set_cursor_on_thread(ThreadlistView *view,
+					  OchushaBBSThread *thread);
 
 void threadlist_view_set_enable_native_search(ThreadlistView *view,
 					      gboolean enable);
