@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.c,v 1.13 2004/01/14 09:59:48 fuyu Exp $
+ * $Id: ochusha_board_category.c,v 1.14 2004/04/13 15:38:05 fuyu Exp $
  */
 
 #include "config.h"
@@ -62,7 +62,7 @@ static void ochusha_board_category_read_boardlist_element(
 						GHashTable *cat_attributes);
 static void ochusha_board_category_write_boardlist_element(
 						OchushaBoardCategory *category,
-						gzFile *boardlist_xml);
+						gzFile boardlist_xml);
 
 
 GType
@@ -399,7 +399,7 @@ ochusha_board_category_read_boardlist_element(OchushaBoardCategory *category,
 
 static void
 ochusha_board_category_write_boardlist_element(OchushaBoardCategory *category,
-					       gzFile *boardlist_xml)
+					       gzFile boardlist_xml)
 {
   OUTPUT_CATEGORY_ATTRIBUTE_STRING(boardlist_xml, category, name);
   OUTPUT_CATEGORY_ATTRIBUTE_BOOLEAN(boardlist_xml, category, hidden);
