@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.71 2004/04/13 15:38:05 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.71.2.1 2004/05/30 14:50:10 fuyu Exp $
  */
 
 #include "config.h"
@@ -722,8 +722,17 @@ process_offlaw_result(WorkerThread *employee, ProcessOfflawResultJobArgs *args)
 	}
       else
 	{
-	  /* Υ顼(¿ʬåIDδڤ) */
+	  /*
+	   * Υ顼
+	   * İžؤбԽʬʤΤǡžΥФ¸ߤ
+	   * ɤ⤦ȤȤ⤳롣
+	   * åIDδڤξloginȤľ
+	   * ٤žΥФۤ٤ġĤȤ
+	   * ĤȤϤΤ0.5ϤǤ֡
+	   */
+	  OchushaAsyncBuffer *old_buffer = cgi_buffer;
 	  OchushaThread2ch *thread_2ch = OCHUSHA_THREAD_2CH(thread);
+	  const char *dat_url;
 	  char *old_url;
 	  const char *encoding
 	    = ochusha_bbs_thread_get_response_character_encoding(thread);
@@ -744,17 +753,56 @@ process_offlaw_result(WorkerThread *employee, ProcessOfflawResultJobArgs *args)
 	    }
 	  else
 	    ochusha_network_broker_output_log(broker,
-					      _("Error by offlaw.cgi"));
+					      _("Error by offlaw.cgi\n"));
 
-	  ochusha_async_buffer_unlock(cgi_buffer);
-	  ochusha_async_buffer_active_unref(cgi_buffer);
-	  ochusha_async_buffer_active_unref(dat_buffer);
+	  dat_url = ochusha_thread_2ch_get_dat_url(thread_2ch);
+	  cgi_buffer = ochusha_network_broker_read_from_url(broker, NULL,
+					dat_url, NULL,
+					OCHUSHA_NETWORK_BROKER_CACHE_ONLY,
+					FALSE,
+					broker->config->thread_chunksize);
+	  if (cgi_buffer == NULL)
+	    {
+	      /*  */
+	      cgi_buffer = old_buffer;
+	      ochusha_async_buffer_unlock(cgi_buffer);
+	      ochusha_async_buffer_active_unref(cgi_buffer);
+	      ochusha_async_buffer_active_unref(dat_buffer);
 
+	      old_url = thread_2ch->oyster_url;
+	      thread_2ch->oyster_url = NULL;
+	      G_FREE(old_url);
+
+	      goto terminated;
+	    }
+	  ochusha_async_buffer_unlock(old_buffer);
+	  ochusha_async_buffer_active_unref(old_buffer);
+	  OCHU_OBJECT_UNREF(old_buffer);
+
+	  if (!ochusha_async_buffer_active_ref(cgi_buffer))
+	    {
+	      ochusha_async_buffer_active_unref(dat_buffer);
+	      goto terminated;
+	    }
+	  ochusha_async_buffer_lock(cgi_buffer);
+
+	  g_signal_connect_swapped(G_OBJECT(cgi_buffer), "access_started",
+			G_CALLBACK(ochusha_async_buffer_emit_access_started),
+			dat_buffer);
+	  g_signal_connect_swapped(G_OBJECT(cgi_buffer), "access_progressed",
+			G_CALLBACK(ochusha_async_buffer_emit_access_progressed),
+			dat_buffer);
+	  g_signal_connect_swapped(G_OBJECT(cgi_buffer), "access_finished",
+			G_CALLBACK(ochusha_async_buffer_emit_access_finished),
+			dat_buffer);
+	  g_signal_connect_swapped(G_OBJECT(cgi_buffer), "access_failed",
+			G_CALLBACK(ochusha_async_buffer_emit_access_failed),
+			dat_buffer);
+
+	  cur_pos = NULL;
 	  old_url = thread_2ch->oyster_url;
 	  thread_2ch->oyster_url = NULL;
 	  G_FREE(old_url);
-
-	  goto terminated;
 	}
     }
 
