@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40.2.1 2004/05/15 16:32:11 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.5 2004/06/08 15:32:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "ochusha.h"
 #include "ochusha_bbs_table.h"
 #include "ochusha_board_2ch.h"
+#include "ochusha_board_jbbs.h"
 #include "ochusha_thread_2ch.h"
 #include "ochusha_utils_2ch.h"
 
@@ -59,7 +60,7 @@ is_thread_id(const char *string)
     return FALSE;
 
   pos = string;
-  if (strchr("123456789", *pos) == NULL)
+  if (strchr("0123456789", *pos) == NULL)
     return FALSE;
 
   pos++;
@@ -684,6 +685,8 @@ is_2ch_board_url(char *url)
     return FALSE;
   if (strstr(url, "del_2ch") != NULL)
     return FALSE;
+  if (strstr(url, "info.2ch.net") != NULL)
+    return FALSE;
   return TRUE;
 }
 
@@ -746,6 +749,10 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 #endif
       board = ochusha_bbs_table_lookup_board_by_url(table, url);
       board_by_name = ochusha_bbs_table_lookup_board_by_name(table, name);
+      if (board_by_name != NULL
+	  && (board_by_name->bbs_type != OCHUSHA_BBS_TYPE_2CH
+	      && board_by_name->bbs_type != OCHUSHA_BBS_TYPE_MACHIBBS))
+	board_by_name = NULL;
 
       if (board == NULL)
 	{
@@ -758,9 +765,17 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	      return FALSE;	/* Out of memory */
 	    }
 
-	  board = ochusha_board_2ch_new(name, url);
 	  if (is_machibbs)
-	    board->bbs_type = OCHUSHA_BBS_TYPE_MACHIBBS;
+	    {
+	      board = ochusha_board_jbbs_new(name, url);
+	      board->bbs_type = OCHUSHA_BBS_TYPE_MACHIBBS;
+	      ochusha_bulletin_board_set_base_url(board, url);	/* ۤ */
+	    }
+	  else
+	    {
+	      board = ochusha_board_2ch_new(name, url);
+	      board->bbs_type = OCHUSHA_BBS_TYPE_2CH;
+	    }
 
 #if GUESS_2CH_BOARD_URL
 	  id = ochusha_bulletin_board_get_id(board);
@@ -772,6 +787,14 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	      goto search_next;
 	    }
 #endif
+	  if (board_by_name != NULL)
+	    {
+	      if (is_machibbs
+		  && board_by_name->bbs_type != OCHUSHA_BBS_TYPE_MACHIBBS)
+		board_by_name = NULL;
+	      else if (board_by_name->bbs_type != OCHUSHA_BBS_TYPE_2CH)
+		board_by_name = NULL;
+	    }
 
 	  if (board_by_name != NULL && board_moved_callback != NULL)
 	    {
@@ -788,13 +811,12 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 		{
 		  /* boardϥơ֥ɲäʤ */
 		  OCHU_OBJECT_UNREF(board);
-		  board = NULL;
-		  goto search_next;
+		  board = board_by_name;
+		  OCHU_OBJECT_REF(board);
 		}
 
 	      if (winner != NULL)
 		{
-		  /* (winner == board)ȸʤ */
 		  ochusha_board_category_remove_board(category, board_by_name);
 		  ochusha_bbs_table_remove_board(table, board_by_name);
 		}
@@ -817,7 +839,8 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	    }
 	}
 
-      if (strstr(url, "bbq.2ch.net") != NULL)
+      if (strstr(url, "headline.2ch.net") != NULL
+	  || strstr(url, "bbq.2ch.net") != NULL)
 	board->bbs_type = OCHUSHA_BBS_TYPE_2CH_HEADLINE;
 
       board->killed = FALSE;
